#########################
# Main file to run code #
#########################

# Housekeeping
exit()
clearconsole()

# Load packages
using LinearAlgebra, Parameters, Plots, Roots

# Load functions
include("Functions/f_Functions.jl")

# Call exogenous parameters
Params = SetParams()

# Plot marginal revenue and marginal cost
plot(Params.ogrid, MarginalCost(Params.ogrid,Params),
    title = "Marginal Revenue and Marginal Cost", titlefontsize=16,
    ylabel="MR and MC", ytickfontsize=12, yguidefontsize=12,
    xlabel="Output", xtickfontsize=12,
    lw=3, label="MC", legendfontsize=8,
    legend=:right )
plot!(Params.ogrid, MarginalRevenue(Params.ogrid,Params),
    lw=3, label="MR")

# Solve for output and prices
output = find_zero(FOC, 0.5)
if abs(FOC(output)) >= 0.000001
    print("Solution not found")
end
price = Params.α - Params.β*output/2.0
cost = Params.γ*(output^2.0)/2.0
profits = price*output - cost
markup = price/MarginalCost(output,Params)

# Display results
print("Results for the monopoly model \n")
println("Output = $output, Price = $price, "*
        "Profits = $profits, and Markups = $markup \n")
