#####################
# Utility Functions #
#####################

# Housekeeping
exit()
clearconsole()

# Load packages
using DataFrames, LinearAlgebra, Parameters, Plots, PrettyTables, XLSX

# Load functions
include("Functions/f_Functions.jl")

# Call exogenous parameters
Params = SetParams()

# Plot Logarithmic utility function
plot(Params.cons, Params.U_log,
    title = "Log Utility", titlefontsize=16,
    ylabel="Utils (u)", ytickfontsize=12, yguidefontsize=12,
    xlabel="Consumption (c)", xtickfontsize=12,
    lw=3, legend=false)

# Plot Exponential utility function
plot(Params.cons, Params.U_exp,
    title = "Exponential Utility", titlefontsize=16,
    ylabel="Utils (u)", ytickfontsize=12, yguidefontsize=12,
    xlabel="Consumption (c)", xtickfontsize=12,
    lw=3, legend=false)

# Plot CRRA utility function
plot(Params.cons, Params.U_CRRA,
    title = "Isoelastic Utility", titlefontsize=16,
    ylabel="Utils (u)", ytickfontsize=12, yguidefontsize=12,
    xlabel="Consumption (c)", xtickfontsize=12,
    lw=3, legend=false)

# Plot Quadratic utility function
plot(Params.cons, Params.U_quad,
    title = "Quadratic Utility", titlefontsize=16,
    ylabel="Utils (u)", ytickfontsize=12, yguidefontsize=12,
    xlabel="Consumption (c)", xtickfontsize=12,
    lw=3, legend=false)
vline!([Params.α/Params.β], lw=3)

## Plot all utility functions together
# Plot Logarithmic utility function
plot(Params.cons, Params.U_log,
    title = "Utility Functions", titlefontsize=16,
    ylabel="Utils (u)", ytickfontsize=12, yguidefontsize=12,
    xlabel="Consumption (c)", xtickfontsize=12,
    lw=3, label="Logarithmic")
# Plot Exponential utility function
plot!(Params.cons, Params.U_exp,
    lw=3, label="Exponential")
# Plot CRRA utility function
plot!(Params.cons, Params.U_CRRA,
    lw=3, label="CRRA")
# Plot Quadratic utility function
plot!(Params.cons, Params.U_quad,
    lw=3, label="Quadratic",
    legendfontsize=10,legend=:bottomright)

## Summary table
Table = OutputTable(Params)
# Export table to an excel file
filename = "UtilityData.xlsx"
XLSX.writetable(filename, Table, overwrite=true, sheetname="Utility", anchor_cell="A1")
